;; Generated package description from crdt.el  -*- no-byte-compile: t -*-
(define-package "crdt" "0.1.2" "Collaborative editing using Conflict-free Replicated Data Types" 'nil :keywords '("collaboration" "crdt") :authors '(("Qiantan Hong" . "qhong@alum.mit.edu")) :maintainer '("Qiantan Hong" . "qhong@alum.mit.edu") :url "https://code.librehq.com/qhong/crdt.el")
